Acknowledging PyAstronomy
======================================

If you make use of PyAstronomy (PyA) in your work,
we are thankful if you acknowledge it by citing its
`ASCL entry <https://ascl.net/1906.010/>`_ (see bibtex entry below) and
give a link to PyAstronomy (https://github.com/sczesla/PyAstronomy), e.g., as
a footnote. PyAstronomy is a collection, so the documentation occasionally points
to further papers, which may be citet as well.

Cheers,
The PyA group

Bibtex entry
-----------------

::
 
     @MISC{pya,
           author = {{Czesla}, Stefan and {Schr{\"o}ter}, Sebastian and
             {Schneider}, Christian P. and {Huber}, Klaus F. and {Pfeifer}, Fabian and
             {Andreasen}, Daniel T. and {Zechmeister}, Mathias},
            title = "{PyA: Python astronomy-related packages}",
         keywords = {Software},
             year = "2019",
            month = "Jun",
              eid = {ascl:1906.010},
            pages = {ascl:1906.010},
    archivePrefix = {ascl},
           eprint = {1906.010},
           adsurl = {https://ui.adsabs.harvard.edu/abs/2019ascl.soft06010C},
          adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }
